# pyhabitat/__init__.py
from .utils import get_version
from .environment import (
    matplotlib_is_available_for_gui_plotting,
    matplotlib_is_available_for_headless_image_export,
    tkinter_is_available,
    in_repl,
    on_freebsd,
    on_linux,
    on_android,
    on_windows,
    on_wsl,
    on_apple,
    on_termux,
    on_pydroid,
    on_ish_alpine,
    as_pyinstaller,
    as_frozen,
    is_elf,
    is_pyz,
    is_windows_portable_executable,
    is_macos_executable,
    is_pipx,
    is_python_script,
    interactive_terminal_is_available,
    web_browser_is_available,
    edit_textfile,
    interp_path,
    main,
    user_darrin_deyoung,
    can_read_input,
    can_spawn_shell,
)

# Optional: Set __all__ for explicit documentation and cleaner imports
__all__ = [
    'matplotlib_is_available_for_gui_plotting',
    'matplotlib_is_available_for_headless_image_export',
    'tkinter_is_available',
    'in_repl',
    'on_termux',
    'on_pydroid',
    'on_wsl',
    'on_freebsd',
    'on_linux',
    'on_android',
    'on_windows',
    'on_apple',
    'on_ish_alpine',
    'as_pyinstaller',
    'as_frozen',
    'is_elf',
    'is_pyz',
    'is_windows_portable_executable',
    'is_macos_executable',
    'is_pipx',
    'is_python_script',
    'interactive_terminal_is_available',
    'web_browser_is_available',
    'edit_textfile',
    'interp_path',
    'main',
    'user_darrin_deyoung',
    'can_read_input',
    'can_spawn_shell',
]

__version__ = get_version()
